#
# spec file for package kf6-breeze-icons
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname breeze-icons
# Full KF6 version (e.g. 6.11.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-breeze-icons
Version:        6.11.0
Release:        1.1
Summary:        Breeze icon theme
License:        LGPL-3.0-only
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  libxml2-tools
# Skip 24px icons generation (saves ~30MB and installs dangling symlinks)
# BuildRequires:  python3 python3-lxml
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
Provides:       breeze5-icons = %{version}
Obsoletes:      breeze5-icons < %{version}

%description
Breeze-icons is a freedesktop.org compatible icon theme.

%package -n libKF6BreezeIcons6
Summary:        Breeze icon theme - icon library

%description -n libKF6BreezeIcons6
Breeze-icons is a freedesktop.org compatible icon theme.
This package provides a library containing icons, resources, and functions
to use them. It is meant to be used for self contained deployments.

%package rcc
Summary:        Breeze icon theme - rcc file
Provides:       breeze5-icons-rcc = %{version}
Obsoletes:      breeze5-icons-rcc < %{version}

%description rcc
Breeze-icons is a freedesktop.org compatible icon theme.
This contains the Breeze (non-dark) icons in a QResource file, used by Kexi.

%package devel
Summary:        CMake config files for kf6-breeze-icons
Requires:       kf6-breeze-icons = %{version}
Requires:       libKF6BreezeIcons6 = %{version}

%description devel
This package provides CMake config files for projects that wish to ensure
the Breeze icons are available at build time.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%define _lto_cflags %{nil}

# kexi needs the icons resource
%cmake_kf6 \
  -DBINARY_ICONS_RESOURCE:BOOL=TRUE \
  -DWITH_ICON_GENERATION:BOOL=FALSE

%kf6_build

%install
%kf6_install

# yast2-theme uses these, but it got renamed in 5.55.0
ln -s yast-software-group.svg %{buildroot}%{_kf6_iconsdir}/breeze/preferences/32/yast-software.svg

%fdupes %{buildroot}%{_kf6_iconsdir}

%icon_theme_cache_create_ghost breeze
%icon_theme_cache_create_ghost breeze-dark

%ldconfig_scriptlets -n libKF6BreezeIcons6

%files
%license COPYING*
%ghost %{_kf6_iconsdir}/breeze/icon-theme.cache
%ghost %{_kf6_iconsdir}/breeze-dark/icon-theme.cache
%exclude %{_kf6_iconsdir}/breeze/breeze-icons.rcc
%exclude %{_kf6_iconsdir}/breeze-dark/breeze-icons-dark.rcc
%{_kf6_iconsdir}/breeze/
%{_kf6_iconsdir}/breeze-dark/

%files -n libKF6BreezeIcons6
%{_kf6_libdir}/libKF6BreezeIcons.so.*

%files rcc
%dir %{_kf6_iconsdir}/breeze
# Kexi does not need the -dark variant.
%{_kf6_iconsdir}/breeze/breeze-icons.rcc

%files devel
%{_kf6_cmakedir}/KF6BreezeIcons/
%{_kf6_includedir}/BreezeIcons/
%{_kf6_libdir}/libKF6BreezeIcons.so

%changelog
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * Add xml/yaml linting
  * Symlink preferences-system-windows-effect-screenshot to applets-screenshooter
  * Provide 12x12 version of open-link icon
  * CI: Add linux-qt6-next build
  * Make the close icons be black X symbols (kde#453167)
  * Update version to 6.11.0
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * create-app-symlinks.py: add cuttlefish (org.kde.iconexplorer)
  * Add new pcmanfm-qt icon
  * Add open-link-symbolic icon
  * Add snap package icon
  * Add symbolic version of preferences-security
  * Add symbolic version of preferences-desktop-emoticons
  * tests: ignore missing index.theme in ScalableTest::test_scalableDuplicates()
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Bring back directory symlinks for breeze-dark (kde#482648)
  * Add symbolic version of system-software-update for small sizes (kde#399139)
  * Also link to 22px versions for Duplicate icons
  * Add symbolic version of preferences-desktop-keyboard-shortcut
  * Add transport-mode-flight icon
  * Add symbolic version of preferences-system-users
  * Add symbolic version of preferences-desktop-notification-symbolic
  * Add symbolic version of preferences-desktop-theme-global
  * Generate index.theme unconditionally to fix qrc/rcc
  * Make qrc generation fail if no *.theme file was found
  * Add missing CSS properties for `blur` and `pixelate` icons (kde#495755)
  * Fix class attribute for places/32/folder-{log,podcast}.svg
  * Add boost and boost-boosted icons
  * Update WINE app icons to match new symbolic versions
  * Add wine-symbolic icon (kde#494450)
  * Add favorite-favorited, change favorite to non-filled
  * Make base donate and help-donate icons be hearts
  * Add love
  * Improve README with more guidelines and contributing information
  * Add icon for keyboard shortcut preferences
  * Add dialog-password icon
  * optimize-svg: Clarify that you need to install svgo globally
  * Add laser printer icon
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Add mimetype icons for text/x-typst
  * Monochromize not-explicitly-colorized symbolic folder icons (kde#494721)
  * Add CI for static builds on Linux
  * Unify common parts of index.theme for breeze and breeze-dark
  * Sync index.theme changes from breeze to breeze-dark (kde#494399)
  * Rename spinbox-* icons to value-*
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Delete 32px colorful folder action icon symlink (kde#478493)
  * Add new knotes-symbolic.svg icon (22/32/48) (kde#398901)
  * format system-suspend-inhibited, system-suspend-uninhibited
  * redesign system-suspend-inhibited, system-suspend-uninhibited
  * Fix recoloring in applications-multimedia-symbolic and applications-engineering-symbolic (kde#492879)
  * Add show-background icon
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Remove 48px draw-freehand symlink (kde#491887)
  * Add info(-symbolic) icon symlinks
  * Add new 64px dialog icons
  * Add icon for Apple Wallet passes bundle
  * Add battery icons with power profile emblems
  * Add remaining symbolic icons required for Discover
  * Update accessibility icons
  * ci: add Alpine/musl job
  * Add system-reboot-update and system-shutdown-update icons
  * Add a couple of missing monochrome category icons
  * don't generate symlinks for app icons if we not install the icons
  * Fix issues with zoom-map icons
  * Add Spinbox-specific decrease and increase icons
  * Make list-remove look like a red X
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Add 22px color (and monochrome, using *-symbolic) category icons. (kde#489347)
  * Make 16px list-remove-symbolic be a link to the base icon
  * Add symlinks for Crow Translate icons (kde#489984)
  * Add flatpak symlink for Git Cola
  * Add icon to indicate adding to a playlist immediately after the current track
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Use newly introduced ColorScheme-Accent (kde#446468)
  * Improve excalamation point placement in data-warning/dialog-warning icon (kde#487626)
  * Add generic translate icon, symlink crow-translate-tray
  * Add non-symbolic base version of network-wireless-bluetooth icons
  * mark as non gui executables to have output on Windows
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Too many changes to list here.
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Add support for media-playlist-no-shuffle icon name
  * Add audio/ogg and audio/x-vorbis+ogg icons
  * Add audio/vnd.wave MIME type
  * Remove generic non-symbolic audio and video icons
  * Add 16 and 22px symbolic versions of some Places icons that were missing (kde#486316)
  * Add zoom-in-map and zoom-out-map icons along with -symbolic versions
  * Longer description for the ICONS_LIBRARY option
  * Add symbolic versions for more USB device style icons
  * Fix some scale errors (kde#485479)
  * Fixed input-combo-on.svg colour issue
  * Add -symbolic symlinks for notification-* icons
  * Use new `dev.suyu_emu.suyu` id, add symlink for old id
  * Add accessories-screenshot-tool icon/symlink
  * [webfont] enable ligatures
  * gitignore: add VS Code dir
  * add input-keyboard-color 22px, 32 px
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Too many changes since 6.0.0, only listing bugfixes:
  * Use magnifying glass iconography for zoom icons (kde#435671)
  * Remove unneeded dark applets icons (kde#477289)
  * Make process-stop-symbolic a symlink to the base icon (kde#482556)
  * fix some 96px folder icons not using accent color (kde#478016)
  * Add new icon for Skladnik BUG: 458214 (kde#458214)
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * The Highlight entry confuses the generator script, so the dark theme will have a dark icon
  * Add folder edit sign encrypt icon
  * fix warnings and output issues even in release builds
  * allow the test to compile with strict flags
  * Add OpenVPN and Cisco VPN file icons
  * update version for new release
  * Move 22px download-later arrow to be a bit more aesthetically pleasing
  * Add upload-later icon for KTorrent
  * Fix cmake config if lib was not build
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-breeze-icons
